==> 12.6.0.tar.gz: webid-on-device-document-scanner-spm/Package.swift <==
// swift-tools-version:5.3
// The swift-tools-version declares the minimum version of Swift required to build this package.

import PackageDescription

let package = Package(
    name: "WebIdOnDeviceDocumentScanner",
    platforms: [
        .iOS(.v13)
    ],
    products: [
        // Products define the executables and libraries a package produces, and make them visible to other packages.
        .library(name: "WebIdOnDeviceDocumentScanner", targets: ["WebIdOnDeviceDocumentScannerWrapper"]),
    ],
    dependencies: [
        // Dependencies declare other packages that this package depends on.
        .package(
            name: "WebIdDocumentScanner",
            url: "https://api.webid-solutions.de/releases/ios/spm/SwiftPackages/webid-document-scanner-spm.git",
            .exact("12.6.0")
        ),
        .package(
            name: "WebIdPluginCore",
            url: "https://api.webid-solutions.de/releases/ios/spm/SwiftPackages/webid-plugin-core-spm.git",
            .exact("12.3.3")
        ),
        .package(
            name: "DocumentReader",
            url: "https://github.com/regulaforensics/DocumentReader-Swift-Package",
            .exact("7.5.4221")
        ),
        .package(
            name: "Full",
            url: "https://github.com/regulaforensics/DocumentReaderFull-Swift-Package",
            .exact("7.5.11015")
        )
    ],
    targets: [
        .binaryTarget(
            name: "WebIdOnDeviceDocumentScanner",
            url: "https://api.webid-solutions.de/releases/ios/xcframework/internal/de/webid-solutions/WebIdOnDeviceDocumentScanner/12.6.0/WebIdOnDeviceDocumentScanner.framework-v12.6.0.zip",
            checksum: "e48581e0deb9bf69a2c498ff19a2722b502d2cd14f64460447f523c846969a02"
        ),
        .target(
            name: "WebIdOnDeviceDocumentScannerWrapper",
            dependencies: [
                .target(name: "WebIdOnDeviceDocumentScanner"),
                // [target dependecies here]
                
                .product(name: "WebIdDocumentScanner", package: "WebIdDocumentScanner"),
                .product(name: "WebIdPluginCore", package: "WebIdPluginCore"),
                .product(name: "DocumentReader", package: "DocumentReader"),
                .product(name: "Full", package: "Full"),
            ]
        )
    ],
    swiftLanguageVersions: [SwiftVersion.v5]
)

==> 20.0.0.tar.gz: webid-on-device-document-scanner-spm/Package.swift <==
// swift-tools-version:5.3
// The swift-tools-version declares the minimum version of Swift required to build this package.

import PackageDescription

let package = Package(
    name: "WebIdOnDeviceDocumentScanner",
    platforms: [
        .iOS(.v13)
    ],
    products: [
        // Products define the executables and libraries a package produces, and make them visible to other packages.
        .library(name: "WebIdOnDeviceDocumentScanner", targets: ["WebIdOnDeviceDocumentScannerWrapper"]),
    ],
    dependencies: [
        // Dependencies declare other packages that this package depends on.
        .package(
            name: "WebIdDocumentScanner",
            url: "https://api.webid-solutions.de/releases/ios/spm/SwiftPackageRedesignV4/webid-document-scanner-spm.git",
            .exact("20.0.0")
        ),
        .package(
            name: "WebIdPluginCore",
            url: "https://api.webid-solutions.de/releases/ios/spm/SwiftPackageRedesignV4/webid-plugin-core-spm.git",
            .exact("20.0.0")
        ),
        .package(
            name: "DocumentReader",
            url: "https://github.com/regulaforensics/DocumentReader-Swift-Package",
            .exact("7.5.4221")
        ),
        .package(
            name: "Full",
            url: "https://github.com/regulaforensics/DocumentReaderFull-Swift-Package",
            .exact("7.5.11015")
        )
    ],
    targets: [
        .binaryTarget(
            name: "WebIdOnDeviceDocumentScanner",
            url: "https://api.webid-solutions.de/releases/ios/xcframework/redesign-v4/de/webid-solutions/WebIdOnDeviceDocumentScanner/20.0.0/WebIdOnDeviceDocumentScanner.framework-v20.0.0.zip",
            checksum: "6801337fcfb032bb7a4f0373be3c1ad23427e7409d39072f620c93efbe2d3a7b"
        ),
        .target(
            name: "WebIdOnDeviceDocumentScannerWrapper",
            dependencies: [
                .target(name: "WebIdOnDeviceDocumentScanner"),
                // [target dependecies here]
                
                .product(name: "WebIdDocumentScanner", package: "WebIdDocumentScanner"),
                .product(name: "WebIdPluginCore", package: "WebIdPluginCore"),
                .product(name: "DocumentReader", package: "DocumentReader"),
                .product(name: "Full", package: "Full"),
            ]
        )
    ],
    swiftLanguageVersions: [SwiftVersion.v5]
)
